Control API Reference — ManipulaPy 1.1.0 Documentation
Description: _api-control: This page documents ManipulaPy.control, the module for manipulator control algorithms with GPU acceleration. — Quick Navigation: — ManipulatorController Class: — Control Strategies: B...

_api-control:

# Control API Reference

This page documents ManipulaPy.control, the module for manipulator control algorithms with GPU acceleration.

Tip

For conceptual explanations, see Control Module User Guide.

—

## Quick Navigation

—

## ManipulatorController Class

—

## Control Strategies

### Basic Controllers

### Advanced Controllers

### Feedforward Control

### Space-Specific Control

—

## State Estimation

—

## Performance Analysis Tools

—

## Auto-Tuning and Limits

—

## See Also

- Dynamics API Reference – Robot dynamics for model-based control

- Kinematics API Reference – Kinematic models for Cartesian control

- Path Planning API Reference – Trajectory reference generation

- Simulation API Reference – Simulator integration and testing tools